@@ -149,7 +149,7 @@ class EventbridgeToStepfunctions(
             log_group_props=log_group_props,
         )
 
-        jsii.create(EventbridgeToStepfunctions, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="eventsRule")
